@@ -31,8 +31,8 @@ class MainLog:
         if not os.path.exists(prefix_path):
             os.mkdir(prefix_path)
         self.prefix_path = prefix_path
-        self.program_log_name = app_name + '-code'
-        self.journal_log_name = app_name + '-info'
+        self.program_log_name = app_name + '_code'
+        self.journal_log_name = app_name + '_info'
         self.host_name = socket.gethostname()
         self.generate_loggers(when, backup_count)
 
@@ -176,11 +176,11 @@ class MainLog:
         logging.getLogger(self.program_log_name).error(message, *args, **kwargs)
 
     def external(self, *args, **kwargs):
-        message = self.journal_model('in', **kwargs)
+        message = self.journal_model('out', **kwargs)
         logging.getLogger(self.journal_log_name).info(message)
 
     def internal(self, *args, **kwargs):
-        message = self.journal_model('out', **kwargs)
+        message = self.journal_model('in', **kwargs)
         logging.getLogger(self.journal_log_name).info(message)
 
     def exception(self, msg, *args, **kwargs):
